@@ -234,7 +234,7 @@ class sqlobj(object):
 
 		for col in list(dataframe.columns):
 			for drop_col, drop_match in drop_columns.items():
-				if col.startswith(drop_col) if dropmatch == 'startswith' else col == drop_col:
+				if col.startswith(drop_col) if drop_match == 'startswith' else col == drop_col:
 					dataframe.drop(columns=[col],inplace=True)
 					break
 
